@@ -32,12 +32,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
+
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 #include <gdk/gdkkeysyms.h>
@@ -49,12 +50,12 @@
 #include <libgnome/gnome-help.h>
 #include <libgnome/gnome-config.h>
 
-/* Note that this file must include gnome-i18n, and not gnome-i18nP, so that
+/* Note that this file must include gi18n, and not gi18n-lib, so that
  * _() is the same as the one seen by the application.  This is moderately
  * bogus; we should just call gettext() directly here.
  */
+#include <glib/gi18n.h>
 
-#include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-program.h>
 #include <libgnome/gnome-gconf.h>
 #include <libgnome/gnome-init.h>
@@ -288,7 +289,7 @@ static GnomeUIInfo menu_defaults[] = {
           0,  (GdkModifierType) 0, NULL }
 };
 
-static gchar *menu_names[] =
+static const gchar *menu_names[] =
 {
   /* 0 */
   "new",
@@ -435,6 +436,8 @@ showing_pixmaps_changed_notify(GConfClient            *client,
                 new_setting = gconf_value_get_bool(value);
         }
 
+	GDK_THREADS_ENTER();
+
         if (new_setting && (mi->image == NULL)) {
                 GtkWidget *pixmap;
                 GnomeUIPixmapType pixmap_type;
@@ -457,6 +460,8 @@ showing_pixmaps_changed_notify(GConfClient            *client,
         } else if (!new_setting && (mi->image != NULL)) {
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), NULL);
         }
+
+	GDK_THREADS_LEAVE();
 }
 
 /* Note that this function is also used for toolbars, don't assume
@@ -1177,7 +1182,7 @@ create_help_entries (GtkMenuShell *menu_shell, GnomeUIInfo *uiinfo, gint pos)
 typedef struct
 {
 	GtkCallbackMarshal relay_func;
-	GtkDestroyNotify destroy_func;
+	GDestroyNotify destroy_func;
 	gpointer user_data;
 } SavedData;
 
@@ -1320,6 +1325,8 @@ menus_have_tearoff_changed_notify(GConfClient            *client,
 	if (entry->value->type != GCONF_VALUE_BOOL)
 		return;
 
+	GDK_THREADS_ENTER();
+
 	menu = GTK_WIDGET (user_data);
 	
 	if (gconf_value_get_bool (entry->value)) {
@@ -1329,7 +1336,7 @@ menus_have_tearoff_changed_notify(GConfClient            *client,
 
 		if (tearoff) {
 			/* Do nothing */
-			return;
+			goto end;
 		}
 		
 		/* Add the tearoff */
@@ -1345,13 +1352,16 @@ menus_have_tearoff_changed_notify(GConfClient            *client,
 
 		if (!tearoff) {
 			/* Do nothing */
-			return;
+			goto end;
 		}
 		
 		/* Remove the tearoff */
 		gtk_widget_destroy (tearoff);
 		g_object_set_data (G_OBJECT (menu), "gnome-app-tearoff", NULL);
 	}
+
+ end:
+	GDK_THREADS_LEAVE();
 }
 
 
@@ -1543,7 +1553,7 @@ gnome_app_create_menus (GnomeApp *app, GnomeUIInfo *uiinfo)
 void
 gnome_app_create_menus_interp (GnomeApp *app, GnomeUIInfo *uiinfo,
 		GtkCallbackMarshal relay_func, gpointer data,
-		GtkDestroyNotify destroy_func)
+		GDestroyNotify destroy_func)
 {
 	GnomeUIBuilderData uibdata;
 
@@ -1949,7 +1959,7 @@ gnome_app_create_toolbar (GnomeApp *app, GnomeUIInfo *uiinfo)
 void
 gnome_app_create_toolbar_interp (GnomeApp *app, GnomeUIInfo *uiinfo,
 				 GtkCallbackMarshal relay_func, gpointer data,
-				 GtkDestroyNotify destroy_func)
+				 GDestroyNotify destroy_func)
 {
 	GnomeUIBuilderData uibdata;
 
@@ -2022,9 +2032,6 @@ gnome_app_create_toolbar_custom (GnomeApp *app, GnomeUIInfo *uiinfo, GnomeUIBuil
 	toolbar = gtk_toolbar_new ();
 	gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
 				     GTK_ORIENTATION_HORIZONTAL);
-	/* FIXME: isn't this set by some of that gtk+2->gconf magic goo? */
-	gtk_toolbar_set_style (GTK_TOOLBAR (toolbar),
-			       GTK_TOOLBAR_BOTH);
 	gnome_app_fill_toolbar_custom(GTK_TOOLBAR (toolbar), uiinfo, uibdata,
 			app->accel_group);
 	gnome_app_set_toolbar (app, GTK_TOOLBAR (toolbar));
@@ -2182,7 +2189,7 @@ gnome_app_find_menu_pos (GtkWidget *parent, const gchar *path, gint *pos)
  * insert the item as the first one in the menubar, "File/" will insert it as
  * the first one in the File menu, "File/Settings" will insert it after the
  * Setting item in the File menu use of "File/<Separator>" should be obvious.
- * However, the use of "<Seperator>" stops after the first separator.
+ * However, the use of "<Separator>" stops after the first separator.
  **/
 
 void
@@ -2389,7 +2396,7 @@ gnome_app_insert_menus_with_data (GnomeApp *app, const gchar *path,
 void
 gnome_app_insert_menus_interp (GnomeApp *app, const gchar *path,
 		GnomeUIInfo *menuinfo, GtkCallbackMarshal relay_func,
-		gpointer data, GtkDestroyNotify destroy_func)
+		gpointer data, GDestroyNotify destroy_func)
 {
 	GnomeUIBuilderData uidata =
 	{
@@ -2446,72 +2453,13 @@ per_app_toolbar_style_changed_notify(GConfClient            *client,
                                          gconf_value_get_string(value),
                                          (gint*)&style)) {
                         got_it = TRUE;
+                        gtk_toolbar_set_style(toolbar, style);
                 }
         }
 
-        /* Fall back to global setting */
-        if (!got_it) {
-                gchar *str;
-
-                str = gconf_client_get_string(client,
-                                              "/desktop/gnome/interface/toolbar_style",
-                                              NULL);
-
-                if (str) {
-			if (!gconf_string_to_enum (toolbar_styles,
-						   str,
-						   (gint *)&style))
-				style = GTK_TOOLBAR_BOTH;
-
-                        g_free(str);
-                }
-        }
-
-        gtk_toolbar_set_style(toolbar, style);
-}
-
-static void
-toolbar_style_changed_notify(GConfClient            *client,
-                             guint                   cnxn_id,
-			     GConfEntry             *entry,
-                             gpointer                user_data)
-{
-        GtkToolbarStyle style = GTK_TOOLBAR_BOTH;
-        GtkWidget *w = user_data;
-        GtkToolbar *toolbar = GTK_TOOLBAR(w);
-        gchar *per_app_key;
-        gchar *str;
-        gboolean got_it = FALSE;
-	GConfValue *value;
-
-        /* Check for app-specific override */
-        per_app_key = gnome_gconf_get_gnome_libs_settings_relative("toolbar_style");
-        str = gconf_client_get_string(client, per_app_key, NULL);
-        g_free(per_app_key);
-
-        if (str) {
-                if (gconf_string_to_enum(toolbar_styles,
-                                         str,
-                                         (gint*)&style)) {
-                        got_it = TRUE;
-                }
-                g_free(str);
-        }
-
-	value = gconf_entry_get_value (entry);
-
-        /* If no per-app setting use this new global setting */
-        if (!got_it &&
-            value &&
-            value->type == GCONF_VALUE_STRING &&
-            gconf_value_get_string(value) != NULL) {
-		if (!gconf_string_to_enum (toolbar_styles,
-					   gconf_value_get_string (value),
-					   (gint *)&style))
-			style = GTK_TOOLBAR_BOTH;
-        }
-
+	GDK_THREADS_ENTER();
         gtk_toolbar_set_style(toolbar, style);
+	GDK_THREADS_LEAVE();
 }
 
 static void
@@ -2765,34 +2713,11 @@ gnome_app_setup_toolbar (GtkToolbar *toolbar,
                                          str,
                                          (gint*)&toolbar_style)) {
                         got_it = TRUE;
+                        gtk_toolbar_set_style (toolbar, toolbar_style);
                 }
 
                 g_free(str);
 
-                /* Try global default */
-                if (!got_it) {
-                        str = gconf_client_get_string(conf,
-                                                      "/desktop/gnome/interface/toolbar_style",
-                                                      NULL);
-
-                        if (str != NULL) {
-                                if (!gconf_string_to_enum(toolbar_styles,
-							  str,
-							  (gint*)&toolbar_style))
-					toolbar_style = GTK_TOOLBAR_BOTH;
-                                g_free(str);
-                        }
-                }
-
-                notify_id = gconf_client_notify_add(conf,
-                                                    "/desktop/gnome/interface/toolbar_style",
-                                                    toolbar_style_changed_notify,
-                                                    toolbar, NULL, NULL);
-
-                g_signal_connect(toolbar, "destroy",
-				 G_CALLBACK(remove_notify_cb),
-				 GINT_TO_POINTER(notify_id));
-
                 notify_id = gconf_client_notify_add(conf,
                                                     per_app_key,
                                                     per_app_toolbar_style_changed_notify,
@@ -2803,8 +2728,6 @@ gnome_app_setup_toolbar (GtkToolbar *toolbar,
 				 GINT_TO_POINTER(notify_id));
 
                 g_free(per_app_key);
-
-                gtk_toolbar_set_style (toolbar, toolbar_style);
         }
 }
 
