@@ -23,18 +23,20 @@
 #ifndef GNOME_HREF_H
 #define GNOME_HREF_H
 
+#ifndef GNOME_DISABLE_DEPRECATED
+
 #include <glib.h>
-#include <gtk/gtkbutton.h>
+#include <gtk/gtk.h>
 
 
 G_BEGIN_DECLS
 
 #define GNOME_TYPE_HREF            (gnome_href_get_type ())
-#define GNOME_HREF(obj)            (GTK_CHECK_CAST((obj), GNOME_TYPE_HREF, GnomeHRef))
-#define GNOME_HREF_CLASS(klass)    (GTK_CHECK_CLASS_CAST((klass), GNOME_TYPE_HREF, GnomeHRefClass))
-#define GNOME_IS_HREF(obj)         (GTK_CHECK_TYPE((obj), GNOME_TYPE_HREF))
-#define GNOME_IS_HREF_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_HREF))
-#define GNOME_HREF_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), GNOME_TYPE_HREF, GnomeHRefClass))
+#define GNOME_HREF(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_TYPE_HREF, GnomeHRef))
+#define GNOME_HREF_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_TYPE_HREF, GnomeHRefClass))
+#define GNOME_IS_HREF(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_TYPE_HREF))
+#define GNOME_IS_HREF_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_HREF))
+#define GNOME_HREF_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_TYPE_HREF, GnomeHRefClass))
 
 typedef struct _GnomeHRef        GnomeHRef;
 typedef struct _GnomeHRefPrivate GnomeHRefPrivate;
@@ -64,9 +66,6 @@ GType gnome_href_get_type(void) G_GNUC_CONST;
 GtkWidget *gnome_href_new(const gchar *url, const gchar *text);
 
 /* for bindings and subclassing, use the gnome_href_new from C */
-void gnome_href_construct(GnomeHRef *href,
-			  const gchar *url,
-			  const gchar *text);
 
 void gnome_href_set_url(GnomeHRef *href, const gchar *url);
 const gchar *gnome_href_get_url(GnomeHRef *href);
@@ -74,13 +73,12 @@ const gchar *gnome_href_get_url(GnomeHRef *href);
 void gnome_href_set_text(GnomeHRef *href, const gchar *text);
 const gchar *gnome_href_get_text(GnomeHRef *href);
 
-#ifndef GNOME_DISABLE_DEPRECATED
-/* DEPRECATED!, use set/get_text */
 void gnome_href_set_label(GnomeHRef *href, const gchar *label);
 const gchar *gnome_href_get_label(GnomeHRef *href);
-#endif /* GNOME_DISABLE_DEPRECATED */
 
 G_END_DECLS
 
+#endif /* GNOME_DISABLE_DEPRECATED */
+
 #endif
 
